@@ -1,27 +1,35 @@
 /**
+ *	This file is part of devilspie2
+ *	Copyright (C) 2001 Havoc Pennington, 2011-2012 Andreas Rönnquist
  *
- *	This file is part of devilspie2.
- *	Copyright (C) 2001 Havoc Pennington, 2011 Andreas Rönnquist
- *
- *	devilspie2 is free software: you can redistribute it and/or modify
- *	it under the terms of the GNU Lesser General Public License as published by
- *	the Free Software Foundation, either version 3 of the License, or
+ *	devilspie2 is free software: you can redistribute it and/or 
+ *	modify it under the terms of the GNU General Public License as published 
+ *	by the Free Software Foundation, either version 3 of the License, or
  *	(at your option) any later version.
- *
+ * 
  *	devilspie2 is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
  *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *	GNU Lesser General Public License for more details.
- *
- *	You should have received a copy of the GNU Lesser General Public License
- *	along with devilspie2.  If not, see <http://www.gnu.org/licenses/>.
- *
+ *	GNU General Public License for more details.
+ * 
+ *	You should have received a copy of the GNU General Public License
+ *	along with devilspie2.  
+ *	If not, see <http://www.gnu.org/licenses/>.
  */
+
 #include <glib.h>
 #include <gdk/gdk.h>
 #include <gdk/gdkx.h>
 #include <X11/Xlib.h>
 
+#include <locale.h>
+
+#include <libintl.h>
+#define _(String) gettext (String)
+#define gettext_noop(String) String
+#define N_(String) gettext_noop (String)
+
+
 #define WNCK_I_KNOW_THIS_IS_UNSTABLE
 #include <libwnck/libwnck.h>
 
@@ -165,7 +173,7 @@ gboolean decorate_window(WnckWindow *window)
 	set_decorations(window,TRUE);
 	
 	if (my_wnck_error_trap_pop()) {
-		g_printerr("decorate_window Failed!\n");
+		g_printerr("decorate_window %s\n",_("Failed!"));
 		return FALSE;
 	}
 	
@@ -183,7 +191,7 @@ gboolean undecorate_window(WnckWindow *window)
 	set_decorations(window,FALSE);
 	
 	if (my_wnck_error_trap_pop()) {
-		g_printerr("decorate_window Failed!\n");
+		g_printerr("decorate_window %s\n", _("Failed!"));
 		return FALSE;
 	}
 	
